<template>
  <v-dialog
  v-model="showDialog"
  width="650"
  >
  <v-card>
    <v-card-title
    class="headline _secondary"
    primary-title
    >
    Please link mobile number to your account
  </v-card-title>
  <v-card-text>
    <v-alert
    :value="true"
    type="info"
    outline
    v-if="info"
    class="mb-3"
    >
    Please Enter a Valid Number
  </v-alert>
  <v-form ref="mobile_form">
    <div class="input-field relative">
      <v-text-field
      name="mobile"
      label="Mobile"
      :mask="mobileMask"
      v-model="veri.mobile"
      :rules="mobileRules"
      type="tel"
      class="mb-2"
      persistent-hint
      hint="Code will be sent on the given mobile number"
      ></v-text-field>
      <v-btn :loading="sending" small flat class="_sendcode" @click="sendOTP">{{ send_otp }}</v-btn>
      <div class="input-field">
        <v-text-field
        name="code"
        label="Enter Verification Code"
        v-model="veri.code"
        hint="You Will Receive Verification Code Via Text or Email **Standard Data Rates May Apply"
        :rules="validateRules"
        :mask="otp_format"
        type="tel"
        class="mb-2"
        ></v-text-field>
      </div>
    </div>
  </v-form>
</v-card-text>
<v-divider></v-divider>
<v-card-actions>
  <v-spacer></v-spacer>
  <v-btn
  large
  color="secondary"
  :loading="sLoading"
  @click="mobileVerify">
  Update
</v-btn>
</v-card-actions>
</v-card>
</v-dialog>
</template>
<script>
import axios from 'axios';
export default {
  props: ['noMobile', 'info', 'customer'],
  data () {
    return {
      showDialog: true,
      veri: [],
      // noMobile: false,
      // info: false,
      send_otp: 'Send Code',
      sending: false,
      sLoading: false,
      otp_format: '###-###',
      mobileMask: 'phone',
      validateRules: [],
      mobileRules: [
          v => !!v && v.length >= 10 || 'Mobile must be 10 digit number'
      ],
    }
  },
  created() {
    this.veri.mobile = this.customer.mobile;
  },
  methods: {
    mobileVerify: function () {
      this.sLoading = true;
      var form_data = new FormData();
      form_data.append('mobile', this.veri.mobile);
      form_data.append('code', this.veri.code);
      axios.post(this.$store.state.api_domain + '?comp=process&action=mobileVerify', form_data, {
        withCredentials: true
      }).then((res) => {
        this.sLoading = false;
        if (res.data.status == 'success') {

          this.showDialog = false;
          this.$store.commit('showSnackBar', res.data.message);

          this.$store.commit('setCustomer', res.data.customer);

        }

        if (res.data.status == 'error') {
          this.$store.commit('showSnackBar', res.data.message);
        }
      });
    },
    sendOTP: function () {
        if (!this.veri.mobile) {
            this.$store.commit('showSnackBar', 'Please add mobile number to send code');
            // return false;
        }

        if (this.veri.mobile) {
            if (this.veri.mobile.length < 10) {
                this.$store.commit('showSnackBar', 'Mobile number should be of 10 digits');
            } else {
                this.send_otp = 'Sending';
                this.sending = true;
                var form_data = new FormData();
                form_data.append('mobile', this.veri.mobile);
                form_data.append('identifier', 'register');
                axios.post(this.$store.state.api_domain + '?comp=process&action=sendOTP', form_data, {withCredentials: true})
                .then((res) => {
                    this.send_otp = 'Code Sent!';
                    this.sending = false;
                    var t = this;
                    setTimeout(function () {
                        t.send_otp = 'Send Code';
                    }, 3000);
                    this.$store.commit('showSnackBar', res.data.message);
                }).catch((e) => {
                  this.send_otp = 'Failed!';
                  this.sending = false;
                  var t = this;
                  setTimeout(function () {
                      t.send_otp = 'Send Code';
                  }, 3000);
                  this.$store.commit('showSnackBar', 'We could not send code');
                });
            }
        }
        return true;
    }
  },
}
</script>
